%define upstream_name    XML-Easy
%define upstream_version 0.011

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 11

Summary:    Basic manipulation of XML data nodes
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/XML/%{upstream_name}-%{upstream_version}.tar.gz
Patch0:     syntax_main.t.diff
# Fix build, from debian:
Patch1:     uvuni_to_utf8_flags.patch

BuildRequires: perl(Encode)
BuildRequires: perl(Exporter)
BuildRequires: perl(IO::File)
BuildRequires: perl(Module::Build)
BuildRequires: perl(Params::Classify)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test::More)
BuildRequires: perl(parent)
BuildRequires: perl(strict)
BuildRequires: perl(utf8)
BuildRequires: perl(warnings)
BuildRequires: perl-devel

%description
the XML::Easy manpage is a collection of modules relating to the
processing, parsing, and serialisation of XML data. It is oriented towards
the use of XML to represent data for interchange purposes, rather than the
use of XML as markup of principally textual data. It does not perform any
schema processing, and does not interpret DTDs or any other kind of schema.
It adheres strictly to the XML specification, in all its awkward details,
except for the aforementioned DTDs.

the XML::Easy manpage strictly separates the in-program manipulation of XML
data from the processing of the textual form of XML. This shields the XML
user from the inconvenient and obscure aspects of XML syntax. XML data
nodes are mainly processed in a clean functional style, using the the
XML::Easy::NodeBasics manpage module. In the (very likely) event that an
application requires some more purpose-specific XML data processing
facilities, they are readily built on top of the XML::Easy::NodeBasics
manpage, retaining the abstraction from textual XML.

When XML must be handled in textual form, for input and output, the the
XML::Easy::Text manpage module supplies a parser and a serialiser. The
interfaces here, too, are functional in nature.

%prep
%autosetup -p0 -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Build.PL --installdirs=vendor
./Build

%check
./Build test

%install
./Build install --destdir=%{buildroot}

%files
%doc Changes META.json META.yml README SIGNATURE
%{_mandir}/man3/*
%perl_vendorarch/XML
%perl_vendorarch/auto/XML


%changelog
* Fri Aug 23 2024 tv <tv> 0.11.0-11.mga10
+ Revision: 2090038
- Fix build
- Rebuild for perl-5.40

* Fri Dec 01 2023 tv <tv> 0.11.0-10.mga10
+ Revision: 2012435
- Rebuild for perl-5.38

* Thu Aug 04 2022 tv <tv> 0.11.0-9.mga9
+ Revision: 1875117
- Rebuild for perl-5.36

* Thu Mar 17 2022 umeabot <umeabot> 0.11.0-8.mga9
+ Revision: 1795327
- Mageia 9 Mass Rebuild

* Sat Jul 18 2020 tv <tv> 0.11.0-7.mga8
+ Revision: 1607006
- rebuild for perl-5.32 (binary package w/o a dep on libperl.so

* Wed Feb 19 2020 umeabot <umeabot> 0.11.0-6.mga8
+ Revision: 1543036
- Mageia 8 Mass Rebuild

* Sat Jan 11 2020 tv <tv> 0.11.0-5.mga8
+ Revision: 1477619
- fix test broken with perl-5.30 (RT#127416)
- rebuild for "lib/XML/Easy.c: loadable library and perl binaries are
  mismatched (got handshake key 0xce00080, needed 0xcd00080)"

* Fri Sep 21 2018 umeabot <umeabot> 0.11.0-4.mga7
+ Revision: 1294042
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 guillomovitch <guillomovitch> 0.11.0-3.mga7
+ Revision: 1248675
- rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 0.11.0-2.mga7
+ Revision: 1167455
- rebuild with fixed rpm for missing autodeps

* Fri Sep 22 2017 guillomovitch <guillomovitch> 0.11.0-1.mga7
+ Revision: 1157106
- new version 0.011

* Sun Jun 19 2016 pterjan <pterjan> 0.9.0-13.mga6
+ Revision: 1035939
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.9.0-12.mga6
+ Revision: 958217
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 0.9.0-11.mga6
+ Revision: 845545
- rebuild for soname-ifed perl

* Tue Jun 23 2015 sander85 <sander85> 0.9.0-10.mga6
+ Revision: 841252
- Rebuild for perl 5.22

* Wed Oct 15 2014 umeabot <umeabot> 0.9.0-9.mga5
+ Revision: 749640
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.0-8.mga5
+ Revision: 686914
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 0.9.0-7.mga5
+ Revision: 632354
- perl 5.20.0 rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.9.0-6.mga4
+ Revision: 525085
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 0.9.0-5.mga4
+ Revision: 431833
- perl 5.18.0 rebuild

* Wed May 29 2013 jquelin <jquelin> 0.9.0-4.mga4
+ Revision: 431283
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.9.0-3.mga3
+ Revision: 374988
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 0.9.0-2.mga3
+ Revision: 251335
- rebuild for perl 5.16

* Sat Nov 05 2011 kharec <kharec> 0.9.0-1.mga2
+ Revision: 163507
- update to 0.009

* Fri Jun 17 2011 jquelin <jquelin> 0.8.0-1.mga2
+ Revision: 109064
- imported package perl-XML-Easy

